
class State:
    unit_mapping = dict()
    group_mapping = dict()
    environment_mapping = dict()

    config = dict()

    meta = dict()

    units = 0
    packages = 0
    repos = 0

    errors = []


